@@ -10,7 +10,9 @@ class AutoMapperDataTypeExpression(AutoMapperDataTypeBase):
         self.value: str = value
 
     def get_column_spec(self, source_df: DataFrame) -> Column:
-        if isinstance(self.value, str):  # if the src column is just string then consider it a sql expression
+        if isinstance(
+            self.value, str
+        ):  # if the src column is just string then consider it a sql expression
             return expr(self.value)
 
         raise ValueError(f"value: {self.value} is not str")
