@@ -26,7 +26,10 @@ def test_auto_mapper_columns(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members", source_view="patients", keys=["member_id"]
+        view="members",
+        source_view="patients",
+        keys=["member_id"],
+        drop_key_columns=False
     ).columns(
         dst1="src1",
         dst2=AutoMapperList(["address1"]),
